@@ -1,6 +1,6 @@
 from .__version__ import __version__
 from .worker import ValiotWorker
-from .worker import QueueType, JobStatus, PollingMode, JobConfigMode, QueryOrderBy
+from .worker import QueueType, JobStatus, PollingMode, JobConfigMode, QueryOrderBy, LogLevel, LogStyle
 from .uploaders import update_job
 
 # * Package name:
