@@ -27,10 +27,12 @@ if not os.environ.get('ENV') == 'prod':
     description='',
     schedule='* * * * *',
     enabled=True,
-    queueType=QueueType.FREQUENCY,
+    queueType=QueueType.ON_DEMAND
 )
-def test_job(**_):
-    print("Hi, I'm test job #1")
+def test_job(log, **_):
+    log(LogLevel.INFO, "Hi, I'm test job #1")
+    time.sleep(0.2)
+    log(LogLevel.INFO, "Hi, I'm test job #1 again")
     return {'result': 'ok 1'}
 
 
@@ -125,7 +127,7 @@ def test_event_job(log, data, **_):
 
 def main():
     print('main for valiot worker')
-    vw.run(interval=5.0)
+    vw.run(interval=1.0)
 
 
 if __name__ == "__main__":
