@@ -62,7 +62,7 @@ query WorkerWaitingJobs($worker: String){
 paginate_stale_jobs = '''
   query WorkerWaitingJobsPaginate(
     $worker: String!
-    $cursor: Int = 0
+    $cursor: String
     $limit: Int = 10
   ){
     jobsPaginate(
