@@ -9,7 +9,9 @@ DEFAULT_REDIS_CONFIG = {
     "host": 'localhost',
     "port": 6379,
     "db": 0,
-    "url": ""
+    "url": "",
+    "socket_timeout": None,
+    "socket_connect_timeout": None,
 }
 
 
@@ -25,22 +27,28 @@ class WorkerRedis():
         self.log = None
         self.gql = GraphQLClient()
 
-    def setRedisConfig(self, host='localhost', port=6379, db=0, url=""):
+    def setRedisConfig(self, host='localhost', port=6379, db=0, url="", socket_timeout=None, socket_connect_timeout=None):
         REDIS_CONFIG = {
             "host": host,
             "port": port,
             "db": db,
-            "url": url
+            "url": url,
+            "socket_timeout": socket_timeout,
+            "socket_connect_timeout": socket_connect_timeout,
         }
         self.redisConfig = REDIS_CONFIG
 
     def setRedisConnection(self):
         if self.redisConfig['url']:
-            self.redis = redis.Redis.from_url(self.redisConfig['url'])
+            self.redis = redis.Redis.from_url(self.redisConfig['url'], 
+                                              socket_connect_timeout=self.redisConfig['socket_connect_timeout'],
+                                              socket_timeout=self.redisConfig['socket_timeout'])
         else:
             self.redis = redis.Redis(host=self.redisConfig['host'],
                                      port=self.redisConfig['port'],
-                                     db=self.redisConfig['db'])
+                                     db=self.redisConfig['db'],
+                                     socket_connect_timeout=self.redisConfig['socket_connect_timeout'],
+                                     socket_timeout=self.redisConfig['socket_timeout'])
 
     def setLog(self, log):
         self.log = log
