@@ -1,9 +1,15 @@
 
-JOB_CREATED = '''
-subscription  JobCreated(
+# we dont care if the job was created or updated, we just want to know if it is waiting to run:
+JOB_WAITING = '''
+subscription  JobWaiting(
   $workerCode: String!
 ){
-  jobCreated(filter: { workerCode: $workerCode }){
+  jobs(
+    filter: {
+      workerCode: $workerCode
+      jobStatus: WAITING
+    }){
+    action
     successful
     messages{field message}
     result{
