@@ -528,9 +528,7 @@ class ValiotWorker():
         }
         data, errors = self.gql.mutate(mutations.create_lock, variables)
         lock = __.get(data, 'result')
-        queue_index = __.arrays.find_index(
-            self.currentQueues, lambda q: q['name'] == queue_name)
-        self.currentQueues[queue_index]['locks'].insert(0, lock)
+        # ! omit lock appending logic, as it's already handled by the subscription (registerLockChangesSubscription)
         return lock  # returns lock object
 
     def unlockQueue(self, queue_name, lock):
@@ -770,6 +768,8 @@ class ValiotWorker():
             lock_index = __.find_index(
                 current_queue['locks'], lambda l: l['id'] == lock['id'])
             if lock_index == -1:
+                log_from_queue(LogLevel.WARNING,
+                        f'Lock not found in current locks list, appending and sorting...')
                 self.currentQueues[queue_index]['locks'].append(lock)
                 self.currentQueues[queue_index]['locks'] = __.sort_by(
                     self.currentQueues[queue_index]['locks'], 'updatedAt', reverse=True)
@@ -847,7 +847,7 @@ class ValiotWorker():
         # * pagination configuration
         workerRegex = f'^{self.worker["code"]}$'  # worker exact match
         limit = 100  # how many jobs to delete in one batch
-        cursor = 0  # starting point for each page
+        cursor = None  # starting point for each page
         hasNextPage = True
         abortedCount = 0
         pages = 0
@@ -858,6 +858,10 @@ class ValiotWorker():
                 variables={'worker': workerRegex,
                            'cursor': cursor, 'limit': limit}
             )
+            if errors:
+                self.log(LogLevel.ERROR, 'Errors deleting stale jobs:')
+                self.log(LogLevel.ERROR, str(errors))
+                break
             jobs = __.get(data, 'jobs', [])
             cursor = __.get(data, 'pageInfo.endCursor')
             hasNextPage = __.get(data, 'pageInfo.hasNextPage')
@@ -871,7 +875,8 @@ class ValiotWorker():
             data, errors = self.gql.mutate(BATCH_STALE_DELETE_MUT)
             if errors:
                 self.log(LogLevel.ERROR, 'Errors deleting stale jobs:')
-                self.log(LogLevel.ERROR, errors)
+                self.log(LogLevel.ERROR, str(errors))
+                break
             self.log(LogLevel.ERROR, f'Deleted {len(jobs)} stale jobs')
             abortedCount += len(jobs)
             pages += 1
@@ -1131,15 +1136,18 @@ class ValiotWorker():
         else:
             self.log(LogLevel.ERROR, 'ERROR SUBSCRIBING TO LOCK CHANGES')
 
-    def registerJobCreatedSubscription(self):
+    def registerJobWaitingSubscription(self):
         """Registers JobCreated subscription that will call certain job when activated"""
         def runOnDemandJob(data):
             """Callback to run when job is created.
             It checks if the job corresponds to active worker or is a dummy subscription call
             """
+            action = __.get(data, 'action')
             job = __.get(data, 'result')
             if not job:
                 return  # Possibly a job for another worker
+            if action == 'deleted':
+                return # we only care about created or updated jobs
             if self.queue_locked(job['queue']['name']):
                 log_from_job = self.getProcessLoggerFunction(
                     queue=job['queue'], job=job)
@@ -1153,7 +1161,7 @@ class ValiotWorker():
                          f"{job['queue']['name']} is DISABLED, skipping job")
 
         self.unsubJobCreated = self.gql.subscribe(
-            query=subscriptions.JOB_CREATED,
+            query=subscriptions.JOB_WAITING,
             # regex makes sure we only get jobs for this worker and not similar ones
             variables={'workerCode': f"^{self.worker['code']}$"},
             callback=runOnDemandJob)
@@ -1547,10 +1555,10 @@ class ValiotWorker():
         self.log(LogLevel.SUCCESS, 'Logging loop started')
 
     def stopLoggingLoop(self):
-        """This function stops de logging loop.
-        """
-        self.stopLogging = True
-        self.loggingProcess.join()
+         """This function stops de logging loop.
+         """
+         self.stopLogging = True
+         self.loggingProcess.join()
 
     def eventLoop(self, interval=1.0):
         """This function manages all generic worker activities.
@@ -1644,7 +1652,7 @@ class ValiotWorker():
             self.log(
                 LogLevel.INFO, 'No config sync performed. If required, set jobConfigMode to SYNC')
         if (self.pollingMode == PollingMode.SUBSCRIPTION):
-            self.registerJobCreatedSubscription()
+            self.registerJobWaitingSubscription()
         self.registerLockChangesSubscription()
         self.registerEventJobs()
         self.registerJobUpdatesListener()
